doapfiend.plugins.fields

Package doapfiend :: Package plugins :: Module fields |
[hide private]
[frames] | no frames]

# Module fields

source code

# Plain text serializer

This plugin outputs DOAP in human-readable plain text

Classes | [hide private]
| OutputPlugin Class for formatting DOAP output

Functions | [hide private]
text |
print_list(doap, field) Print list of DOAP attributes | source code
text |
print_field(doap, field) Print single field | source code
print_repos(doap, repo, field) Prints DOAP repository metadata | source code
get_people(doap, job) Print people for a particular job | source code
get_releases(doap, brief=False) Print DOAP package release metadata | source code

Variables | [hide private]
| FOAF = `rdflib.URIRef('http://xmlns.com/foaf/0.1/')`
| LOG = `logging.getLogger('doapfiend')`

Function Details | [hide private]

### print_list(doap, field) | source code
Print list of DOAP attributes Parameters: `doap` (text) - DOAP in RDF/XML `field` (text) - DOAP attribute to be printed Returns: text Field to be printed

### print_field(doap, field) | source code
Print single field Parameters: `doap` (text) - DOAP in RDF/XML `field` (text) - DOAP attribute to be printed Returns: text Field to be printed